Method: Aws::ElasticTranscoder::Types::AudioParameters#codec_options

Defined in:
lib/aws-sdk-elastictranscoder/types.rb

#codec_optionsTypes::AudioCodecOptions

If you specified AAC for Audio:Codec, this is the AAC compression profile to use. Valid values include:

auto, AAC-LC, HE-AAC, HE-AACv2

If you specify auto, Elastic Transcoder chooses a profile based on the bit rate of the output file.



369
370
371
372
373
374
375
376
377
378
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 369

class AudioParameters < Struct.new(
  :codec,
  :sample_rate,
  :bit_rate,
  :channels,
  :audio_packing_mode,
  :codec_options)
  SENSITIVE = []
  include Aws::Structure
end