Class: Aws::ElasticTranscoder::Types::CreateJobPlaylist
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::CreateJobPlaylist
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
Information about the master playlist.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#format ⇒ String
The format of the output playlist.
-
#hls_content_protection ⇒ Types::HlsContentProtection
The HLS content protection settings, if any, that you want Elastic Transcoder to apply to the output files associated with this playlist.
-
#name ⇒ String
The name that you want Elastic Transcoder to assign to the master playlist, for example, nyc-vacation.m3u8.
-
#output_keys ⇒ Array<String>
For each output in this job that you want to include in a master playlist, the value of the
Outputs:Keyobject. -
#play_ready_drm ⇒ Types::PlayReadyDrm
The DRM settings, if any, that you want Elastic Transcoder to apply to the output files associated with this playlist.
Instance Attribute Details
#format ⇒ String
The format of the output playlist. Valid formats include HLSv3, HLSv4, and Smooth.
842 843 844 845 846 847 848 849 850 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 842 class CreateJobPlaylist < Struct.new( :name, :format, :output_keys, :hls_content_protection, :play_ready_drm) SENSITIVE = [] include Aws::Structure end |
#hls_content_protection ⇒ Types::HlsContentProtection
The HLS content protection settings, if any, that you want Elastic Transcoder to apply to the output files associated with this playlist.
842 843 844 845 846 847 848 849 850 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 842 class CreateJobPlaylist < Struct.new( :name, :format, :output_keys, :hls_content_protection, :play_ready_drm) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you want Elastic Transcoder to assign to the master playlist, for example, nyc-vacation.m3u8. If the name includes a / character, the section of the name before the last / must be identical for all Name objects. If you create more than one master playlist, the values of all Name objects must be unique.
<note markdown=“1”> Elastic Transcoder automatically appends the relevant file extension to the file name (.m3u8 for HLSv3 and HLSv4 playlists, and .ism and .ismc for Smooth playlists). If you include a file extension in Name, the file name will have two extensions.
</note>
842 843 844 845 846 847 848 849 850 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 842 class CreateJobPlaylist < Struct.new( :name, :format, :output_keys, :hls_content_protection, :play_ready_drm) SENSITIVE = [] include Aws::Structure end |
#output_keys ⇒ Array<String>
For each output in this job that you want to include in a master playlist, the value of the Outputs:Key object.
-
If your output is not
HLSor does not have a segment duration set, the name of the output file is a concatenation ofOutputKeyPrefixandOutputs:Key:OutputKeyPrefix`Outputs:Key`
-
If your output is
HLSv3and has a segment duration set, or is not included in a playlist, Elastic Transcoder creates an output playlist file with a file extension of.m3u8, and a series of.tsfiles that include a five-digit sequential counter beginning with 00000:OutputKeyPrefix`Outputs:Key`.m3u8
OutputKeyPrefix`Outputs:Key`00000.ts
-
If your output is
HLSv4, has a segment duration set, and is included in anHLSv4playlist, Elastic Transcoder creates an output playlist file with a file extension of_v4.m3u8. If the output is video, Elastic Transcoder also creates an output file with an extension of_iframe.m3u8:OutputKeyPrefix`Outputs:Key`_v4.m3u8
OutputKeyPrefix`Outputs:Key`_iframe.m3u8
OutputKeyPrefix`Outputs:Key`.ts
Elastic Transcoder automatically appends the relevant file extension to the file name. If you include a file extension in Output Key, the file name will have two extensions.
If you include more than one output in a playlist, any segment duration settings, clip settings, or caption settings must be the same for all outputs in the playlist. For Smooth playlists, the Audio:Profile, Video:Profile, and Video:FrameRate to Video:KeyframesMaxDist ratio must be the same for all outputs.
842 843 844 845 846 847 848 849 850 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 842 class CreateJobPlaylist < Struct.new( :name, :format, :output_keys, :hls_content_protection, :play_ready_drm) SENSITIVE = [] include Aws::Structure end |
#play_ready_drm ⇒ Types::PlayReadyDrm
The DRM settings, if any, that you want Elastic Transcoder to apply to the output files associated with this playlist.
842 843 844 845 846 847 848 849 850 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 842 class CreateJobPlaylist < Struct.new( :name, :format, :output_keys, :hls_content_protection, :play_ready_drm) SENSITIVE = [] include Aws::Structure end |