Class: Aws::ElasticTranscoder::Types::CreatePipelineResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elastictranscoder/types.rb

Overview

When you create a pipeline, Elastic Transcoder returns the values that you specified in the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pipelineTypes::Pipeline

A section of the response body that provides information about the pipeline that is created.

Returns:



1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 1197

class CreatePipelineResponse < Struct.new(
  :pipeline,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#warningsArray<Types::Warning>

Elastic Transcoder returns a warning if the resources used by your pipeline are not in the same region as the pipeline.

Using resources in the same region, such as your Amazon S3 buckets, Amazon SNS notification topics, and AWS KMS key, reduces processing time and prevents cross-regional charges.

Returns:



1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 1197

class CreatePipelineResponse < Struct.new(
  :pipeline,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end