Class: Aws::ElasticTranscoder::Types::DeletePresetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::DeletePresetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
The DeletePresetRequest structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the preset for which you want to get detailed information.
Instance Attribute Details
#id ⇒ String
The identifier of the preset for which you want to get detailed information.
1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 1290 class DeletePresetRequest < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |