Method: Aws::ElasticTranscoder::Types::JobInput#resolution

Defined in:
lib/aws-sdk-elastictranscoder/types.rb

#resolutionString

This value must be auto, which causes Elastic Transcoder to automatically detect the resolution of the input file.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 1820

class JobInput < Struct.new(
  :key,
  :frame_rate,
  :resolution,
  :aspect_ratio,
  :interlaced,
  :container,
  :encryption,
  :time_span,
  :input_captions,
  :detected_properties)
  SENSITIVE = []
  include Aws::Structure
end