Class: Aws::ElasticTranscoder::Types::ListJobsByStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::ListJobsByStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
The ListJobsByStatusRequest structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ascending ⇒ String
To list jobs in chronological order by the date and time that they were submitted, enter
true. -
#page_token ⇒ String
When Elastic Transcoder returns more than one page of results, use
pageTokenin subsequentGETrequests to get each successive page of results. -
#status ⇒ String
To get information about all of the jobs associated with the current AWS account that have a given status, specify the following status:
Submitted,Progressing,Complete,Canceled, orError.
Instance Attribute Details
#ascending ⇒ String
To list jobs in chronological order by the date and time that they were submitted, enter true. To list jobs in reverse chronological order, enter false.
2223 2224 2225 2226 2227 2228 2229 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2223 class ListJobsByStatusRequest < Struct.new( :status, :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |
#page_token ⇒ String
When Elastic Transcoder returns more than one page of results, use pageToken in subsequent GET requests to get each successive page of results.
2223 2224 2225 2226 2227 2228 2229 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2223 class ListJobsByStatusRequest < Struct.new( :status, :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
To get information about all of the jobs associated with the current AWS account that have a given status, specify the following status: Submitted, Progressing, Complete, Canceled, or Error.
2223 2224 2225 2226 2227 2228 2229 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2223 class ListJobsByStatusRequest < Struct.new( :status, :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |