Class: Aws::ElasticTranscoder::Types::ListPipelinesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::ListPipelinesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
The ListPipelineRequest structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ascending ⇒ String
To list pipelines in chronological order by the date and time that they were created, enter
true. -
#page_token ⇒ String
When Elastic Transcoder returns more than one page of results, use
pageTokenin subsequentGETrequests to get each successive page of results.
Instance Attribute Details
#ascending ⇒ String
To list pipelines in chronological order by the date and time that they were created, enter true. To list pipelines in reverse chronological order, enter false.
2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2265 class ListPipelinesRequest < Struct.new( :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |
#page_token ⇒ String
When Elastic Transcoder returns more than one page of results, use pageToken in subsequent GET requests to get each successive page of results.
2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2265 class ListPipelinesRequest < Struct.new( :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |