Class: Aws::ElasticTranscoder::Types::ListPipelinesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::ListPipelinesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
A list of the pipelines associated with the current AWS account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A value that you use to access the second and subsequent pages of results, if any.
-
#pipelines ⇒ Array<Types::Pipeline>
An array of
Pipelineobjects.
Instance Attribute Details
#next_page_token ⇒ String
A value that you use to access the second and subsequent pages of results, if any. When the pipelines fit on one page or when you’ve reached the last page of results, the value of NextPageToken is null.
2285 2286 2287 2288 2289 2290 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2285 class ListPipelinesResponse < Struct.new( :pipelines, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#pipelines ⇒ Array<Types::Pipeline>
An array of Pipeline objects.
2285 2286 2287 2288 2289 2290 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2285 class ListPipelinesResponse < Struct.new( :pipelines, :next_page_token) SENSITIVE = [] include Aws::Structure end |