Class: Aws::ElasticTranscoder::Types::ListPresetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::ListPresetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
The ListPresetsRequest structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ascending ⇒ String
To list presets in chronological order by the date and time that they were created, enter
true. -
#page_token ⇒ String
When Elastic Transcoder returns more than one page of results, use
pageTokenin subsequentGETrequests to get each successive page of results.
Instance Attribute Details
#ascending ⇒ String
To list presets in chronological order by the date and time that
they were created, enter true. To list presets in reverse
chronological order, enter false.
2306 2307 2308 2309 2310 2311 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2306 class ListPresetsRequest < Struct.new( :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |
#page_token ⇒ String
When Elastic Transcoder returns more than one page of results, use
pageToken in subsequent GET requests to get each successive page
of results.
2306 2307 2308 2309 2310 2311 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2306 class ListPresetsRequest < Struct.new( :ascending, :page_token) SENSITIVE = [] include Aws::Structure end |