Class: Aws::ElasticTranscoder::Types::ListPresetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticTranscoder::Types::ListPresetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elastictranscoder/types.rb
Overview
The ListPresetsResponse structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A value that you use to access the second and subsequent pages of results, if any.
-
#presets ⇒ Array<Types::Preset>
An array of
Presetobjects.
Instance Attribute Details
#next_page_token ⇒ String
A value that you use to access the second and subsequent pages of results, if any. When the presets fit on one page or when you’ve reached the last page of results, the value of NextPageToken is null.
2326 2327 2328 2329 2330 2331 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2326 class ListPresetsResponse < Struct.new( :presets, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#presets ⇒ Array<Types::Preset>
An array of Preset objects.
2326 2327 2328 2329 2330 2331 |
# File 'lib/aws-sdk-elastictranscoder/types.rb', line 2326 class ListPresetsResponse < Struct.new( :presets, :next_page_token) SENSITIVE = [] include Aws::Structure end |